@@ -1,6 +1,8 @@
 #' @importFrom dplyr bind_cols bind_rows
 #' @importFrom rlang .data
-get_predictions_polr <- function(model, fitfram, ci.lvl, linv, typical, terms, fun, vcov.fun, vcov.type, vcov.args, condition, interval, ...) {
+get_predictions_polr <- function(model, fitfram, ci.lvl, linv, typical, terms, model.class, vcov.fun, vcov.type, vcov.args, condition, interval, ...) {
+
+  se <- (!is.null(ci.lvl) && !is.na(ci.lvl)) || !is.null(vcov.fun)
 
   # compute ci, two-ways
   if (!is.null(ci.lvl) && !is.na(ci.lvl))
@@ -27,7 +29,7 @@ get_predictions_polr <- function(model, fitfram, ci.lvl, linv, typical, terms, f
   }
 
   # bind predictions to model frame
-  fitfram <- dplyr::bind_cols(prdat, fitfram)
+  fitfram <- cbind(prdat, fitfram)
 
   # for proportional ordinal logistic regression (see MASS::polr),
   # we have predicted values for each response category. Hence,
@@ -36,12 +38,12 @@ get_predictions_polr <- function(model, fitfram, ci.lvl, linv, typical, terms, f
   fitfram <- .gather(fitfram, "response.level", "predicted", colnames(prdat))
 
   se.pred <-
-    get_se_from_vcov(
+    .get_se_from_vcov(
       model = model,
       fitfram = fitfram,
       typical = typical,
       terms = terms,
-      fun = fun,
+      model.class = model.class,
       vcov.fun = vcov.fun,
       vcov.type = vcov.type,
       vcov.args = vcov.args,
@@ -49,7 +51,7 @@ get_predictions_polr <- function(model, fitfram, ci.lvl, linv, typical, terms, f
       interval = interval
     )
 
-  if (!is.null(se.pred)) {
+  if (!is.null(se.pred) && isTRUE(se)) {
     se.fit <- se.pred$se.fit
     fitfram <- se.pred$fitfram
 
