@@ -8,28 +8,30 @@
 #'   \code{ggeffect()} computes marginal effects by internally calling
 #'   \code{\link[effects]{Effect}}, while \code{ggemmeans()} computes marginal
 #'   effects by internally calling \code{\link[emmeans]{emmeans}}.
-#'   \code{ggaverage()} computes the average predicted values. The result is
-#'   returned as tidy data frame.
+#'   The result is returned as consistent data frame.
 #'
 #' @param model A fitted model object, or a list of model objects. Any model
 #'   that supports common methods like \code{predict()}, \code{family()}
 #'   or \code{model.frame()} should work. For \code{ggeffect()}, any model
-#'   that is supported by the \CRANpkg{effects}-package should work.
+#'   that is supported by \CRANpkg{effects} should work, and for
+#'   \code{ggemmeans()}, all models supported by \CRANpkg{emmeans} should work.
 #' @param terms Character vector (or a formula) with the names of those terms
 #'   from \code{model}, for which marginal effects should be displayed. At least
 #'   one term is required to calculate effects for certain terms, maximum length is
-#'   three terms, where the second and third term indicate the groups, i.e.
-#'   predictions of first term are grouped by the values of the second (and third)
-#'   term. If \code{terms} is missing or \code{NULL}, marginal effects for each
+#'   four terms, where the second to fourth term indicate the groups, i.e.
+#'   predictions of first term are grouped by the values of the remaining
+#'   terms. If \code{terms} is missing or \code{NULL}, marginal effects for each
 #'   model term are calculated. It is also possible to define specific values for
 #'   terms, at which marginal effects should be calculated (see 'Details').
 #'   All remaining covariates that are not specified in \code{terms} are held
-#'   constant (if \code{full.data = FALSE}, the default) or are set to the
-#'   values from the observations (i.e. are kept as they happen to be;
-#'   see 'Details'). See also argument \code{condition} and \code{typical}.
+#'   constant (see 'Details'). See also arguments \code{condition} and \code{typical}.
 #' @param ci.lvl Numeric, the level of the confidence intervals. For \code{ggpredict()},
 #'   use \code{ci.lvl = NA}, if confidence intervals should not be calculated
-#'   (for instance, due to computation time).
+#'   (for instance, due to computation time). Typically, confidence intervals
+#'   based on the standard errors as returned by the \code{predict()} function
+#'   are returned, assuming normal distribution (i.e. \code{+/- 1.96 * SE}).
+#'   See introduction of \href{https://strengejacke.github.io/ggeffects/articles/ggeffects.html}{this vignette}
+#'   for more details.
 #' @param type Character, only applies for survival models, mixed effects models
 #'   and/or models with zero-inflation. \strong{Note:} For \code{brmsfit}-models
 #'   with zero-inflation component, there is no \code{type = "fe.zi"} nor
@@ -60,7 +62,7 @@
 #'     \cr \cr
 #'     To get predicted values for each level of the random effects groups, add the
 #'     name of the related random effect term to the \code{terms}-argument
-#'     (for more details, see \href{../doc/effectsatvalues.html}{this vignette}).
+#'     (for more details, see \href{https://strengejacke.github.io/ggeffects/articles/introduction_effectsatvalues.html}{this vignette}).
 #'     }
 #'     \item{\code{"fe.zi"}}{
 #'     Predicted values are conditioned on the fixed effects and the zero-inflation
@@ -95,17 +97,12 @@
 #'     Only used internally.
 #'     }
 #'   }
-#' @param full.data Logical, if \code{TRUE}, the returned data frame contains
-#'   predictions for all observations. This data frame also has columns
-#'   for residuals and observed values, and can also be used to plot a
-#'   scatter plot of all data points or fitted values.
-#'   If \code{FALSE} (the default), the returned data frame only contains
-#'   predictions for all combinations of unique values of the model's
-#'   predictors. Residuals and observed values are set to \code{NA}.
-#'   Usually, this argument is only used internally by \code{ggaverage()}.
 #' @param typical Character vector, naming the function to be applied to the
 #'   covariates over which the effect is "averaged". The default is "mean".
 #'   See \code{\link[sjmisc]{typical_value}} for options.
+#' @param back.transform Logical, if \code{TRUE} (the default), predicted values
+#'   for log- or log-log transformend responses will be back-transformed to
+#'   original response-scale.
 #' @param ppd Logical, if \code{TRUE}, predictions for Stan-models are
 #'   based on the posterior predictive distribution
 #'   (\code{\link[rstantools]{posterior_predict}}). If \code{FALSE} (the
@@ -113,13 +110,13 @@
 #'   predictor (\code{\link[rstantools]{posterior_linpred}}).
 #' @param x.as.factor,x.cat Logical, if \code{TRUE}, preserves factor-class as
 #'   \code{x}-column in the returned data frame (only applies if first variable
-#'   in \code{terms} is a factor). By default, the \code{x}-column is always
+#'   in \code{terms} is a factor). If \code{FALSE}, the \code{x}-column is always
 #'   numeric. This argument is useful when building own plots from the data,
-#'   based on ggplot, so you don't need to coerce \code{x} to factor. The
+#'   based on ggplot, so you don't need to coerce \code{x} to numeric. The
 #'   \code{plot()}-method, however, automatically uses continuous or discrete
 #'   x-scales, depending on the variable-type. For more details, see
-#'   \href{../doc/plotmethod.html}{the plot-vignette} and the
-#'   \href{../doc/marginaleffects.html}{the vignette on package-basics}.
+#'   \href{https://strengejacke.github.io/ggeffects/articles/introduction_plotmethod.html}{the plot-vignette} and the
+#'   \href{https://strengejacke.github.io/ggeffects/articles/ggeffects.html}{the vignette on package-basics}.
 #'   \code{x.cat} is an alias for \code{x.as.factor}.
 #' @param condition Named character vector, which indicates covariates that
 #'   should be held constant at specific values. Unlike \code{typical}, which
@@ -132,7 +129,7 @@
 #'   residual variance (sigma^2). This argument is ignored for mixed models,
 #'   as \code{interval = "prediction"} is equivalent to \code{type = "re"}
 #'   (and \code{interval = "confidence"} is equivalent to \code{type = "fe"}).
-#'   Note that not all prediction intervals are not available for all models.
+#'   Note that prediction intervals are not available for all models.
 #' @param vcov.fun String, indicating the name of the \code{vcov*()}-function
 #'    from the \pkg{sandwich}-package, e.g. \code{vcov.fun = "vcovCL"},
 #'    which is used to compute robust standard errors for predictions.
@@ -153,38 +150,35 @@
 #'    simulation, e.g. \code{nsim = 500}.
 #'
 #' @details
-#'   \strong{Supported Models}
-#'   \cr \cr
+#'   \subsection{Supported Models}{
 #'   Currently supported model-objects are (in alphabetical order):
-#'   \code{betareg}, \code{bglmer}, \code{blmer}, \code{brglm}, \code{brmsfit},
+#'   \code{betabin}, \code{betareg}, \code{bglmer}, \code{blmer}, \code{brglm}, \code{brmsfit},
 #'   \code{clm}, \code{clm2}, \code{clmm}, \code{coxph}, \code{gam} (package \pkg{mgcv}),
 #'   \code{Gam} (package \pkg{gam}), \code{gamlss}, \code{gamm}, \code{gamm4},
 #'   \code{gee}, \code{geeglm}, \code{glm}, \code{glm.nb}, \code{glmer},
 #'   \code{glmer.nb}, \code{glmmTMB}, \code{glmmPQL}, \code{glmrob}, \code{glmRob},
 #'   \code{gls}, \code{hurdle}, \code{ivreg}, \code{lm}, \code{lm_robust}, \code{lme},
 #'   \code{lmer}, \code{lmrob}, \code{lmRob}, \code{logistf}, \code{lrm},
-#'   \code{MixMod}, \code{MCMCglmm}, \code{multinom}, \code{nlmer}, \code{ols}, \code{plm},
+#'   \code{MixMod}, \code{MCMCglmm}, \code{multinom}, \code{negbin}, \code{nlmer}, \code{ols}, \code{plm},
 #'   \code{polr}, \code{rlm}, \code{rlmer}, \code{rq}, \code{rqss},
 #'   \code{stanreg}, \code{survreg}, \code{svyglm}, \code{svyglm.nb},
-#'   \code{tobit}, \code{truncreg}, \code{vgam}, \code{zeroinfl} and \code{zerotrunc}.
+#'   \code{tobit}, \code{truncreg}, \code{vgam}, \code{wbm}, \code{zeroinfl} and \code{zerotrunc}.
 #'   Other models not listed here are passed to a generic predict-function
 #'   and might work as well, or maybe with \code{ggeffect()} or \code{ggemmeans()},
 #'   which effectively do the same as \code{ggpredict()}. The main difference
 #'   is that \code{ggpredict()} calls \code{predict()}, while \code{ggeffect()}
 #'   calls \code{\link[effects]{Effect}} and \code{ggemmeans()} calls
 #'   \code{\link[emmeans]{emmeans}} to compute marginal effects.
-#'   \cr \cr
-#'   \strong{Difference between \code{ggpredict()} and \code{ggeffect()} or \code{ggemmeans()}}
-#'   \cr \cr
+#'   }
+#'   \subsection{Difference between \code{ggpredict()} and \code{ggeffect()} or \code{ggemmeans()}}{
 #'   \code{ggpredict()} and \code{ggeffect()} resp. \code{ggemmeans()} differ in
 #'   how factors are held constant: \code{ggpredict()} uses the reference level, while
 #'   \code{ggeffect()} and \code{ggemmeans()} compute a kind of "average" value,
 #'   which represents the proportions of each factor's category. Use \code{condition}
 #'   to set a specific level for factors in \code{ggemmeans()}, so factors are
 #'   not averaged over their categories, but held constant at a given level.
-#'   \cr \cr
-#'   \strong{Marginal Effects at Specific Values}
-#'   \cr \cr
+#'   }
+#'   \subsection{Marginal Effects at Specific Values}{
 #'   Specific values of model terms can be specified via the \code{terms}-argument.
 #'   Indicating levels in square brackets allows for selecting only
 #'   specific groups or values resp. value ranges. Term name and the start of
@@ -193,7 +187,7 @@
 #'   with colon, are also allowed: \code{terms = c("education", "age [30:60]")}.
 #'   \cr \cr
 #'   The \code{terms}-argument also supports the same shortcuts as the
-#'   \code{values}-argument in \code{rprs_values()}. So
+#'   \code{values}-argument in \code{values_at()}. So
 #'   \code{terms = "age [meansd]"} would return predictions for the values
 #'   one standard deviation below the mean age, the mean age and
 #'   one SD above the mean age. \code{terms = "age [quart2]"} would calculate
@@ -204,20 +198,20 @@
 #'   This is useful when model predictors were transformed for fitting the
 #'   model and should be back-transformed to the original scale for predictions.
 #'   It is also possible to define own functions (see
-#'   \href{../doc/effectsatvalues.html}{this vignette}).
+#'   \href{https://strengejacke.github.io/ggeffects/articles/introduction_effectsatvalues.html}{this vignette}).
 #'   \cr \cr
 #'   You can take a random sample of any size with \code{sample=n}, e.g
 #'   \code{terms = "income [sample=8]"}, which will sample eight values from
 #'   all possible values of the variable \code{income}. This option is especially
 #'   useful for plotting marginal effects at certain levels of random effects
 #'   group levels, where the group factor has many levels that can be completely
-#'   plotted. For more details, see \href{../doc/effectsatvalues.html}{this vignette}.
+#'   plotted. For more details, see \href{https://strengejacke.github.io/ggeffects/articles/introduction_effectsatvalues.html}{this vignette}.
 #'   \cr \cr
 #'   Finally, numeric vectors for which no specific values are given, a
 #'   "pretty range" is calculated (see \code{\link{pretty_range}}), to avoid
 #'   memory allocation problems for vectors with many unique values. If a numeric
 #'   vector is specified as second or third term (i.e. if this vector represents
-#'   a grouping structure), representative values (see \code{\link{rprs_values}})
+#'   a grouping structure), representative values (see \code{\link{values_at}})
 #'   are chosen (unless other values are specified). If all values for a numeric
 #'   vector should be used to compute predictions, you may use e.g.
 #'   \code{terms = "age [all]"}. See also package vignettes.
@@ -226,38 +220,25 @@
 #'   range (i.e. if no specific values would be given), use the \code{n}-tag,
 #'   e.g. \code{terms="age [n=5]"} or \code{terms="age [n=12]"}. Larger
 #'   values for \code{n} return a larger range of predicted values.
-#'   \cr \cr
-#'   \strong{Holding covariates at constant values}
-#'   \cr \cr
-#'   For \code{ggpredict()}, if \code{full.data = FALSE}, \code{expand.grid()}
-#'   is called on all unique combinations of \code{model.frame(model)[, terms]}
-#'   and used as \code{newdata}-argument for \code{predict()}. In this case,
+#'   }
+#'   \subsection{Holding covariates at constant values}{
+#'   For \code{ggpredict()}, \code{expand.grid()} is called on all unique
+#'   combinations of \code{model.frame(model)[, terms]} and used as
+#'   \code{newdata}-argument for \code{predict()}. In this case,
 #'   all remaining covariates that are not specified in \code{terms} are
 #'   held constant: Numeric values are set to the mean (unless changed with
 #'   the \code{condition} or \code{typical}-argument), factors are set to their
 #'   reference level (may also be changed with \code{condition}) and character
 #'   vectors to their mode (most common element).
 #'   \cr \cr
-#'   \code{ggaverage()} computes the average predicted values, by calling
-#'   \code{ggpredict()} with \code{full.data = TRUE}, where argument
-#'   \code{newdata = model.frame(model)} is used in \code{predict()}.
-#'   Hence, predictions are made on the model data. In this case, all
-#'   remaining covariates that are not specified in \code{terms} are
-#'   \emph{not} held constant, but vary between observations (and are
-#'   kept as they happen to be). The predicted values are then averaged
-#'   for each group (if any). Thus, \code{ggpredict()} can be considered
-#'   as calculating marginal effects at the mean, while \code{ggaverage()}
-#'   computes average marginal effects.
-#'   \cr \cr
 #'   \code{ggeffect()} and \code{ggemmeans()}, by default, set remaining numeric
 #'   covariates to their mean value, while for factors, a kind of "average" value,
 #'   which represents the proportions of each factor's category, is used. For
 #'   \code{ggemmeans()}, use \code{condition} to set a specific level for
 #'   factors so that these are not averaged over their categories, but held
 #'   constant at the given level.
-#'   \cr \cr
-#'   \strong{Bayesian Regression Models}
-#'   \cr \cr
+#'   }
+#'   \subsection{Bayesian Regression Models}{
 #'   \code{ggpredict()} also works with \strong{Stan}-models from
 #'   the \CRANpkg{rstanarm} or \CRANpkg{brms}-package. The predicted
 #'   values are the median value of all drawn posterior samples. The
@@ -267,17 +248,15 @@
 #'   limitations: the uncertainty of the error term is not taken into
 #'   account. The recommendation is to use the posterior predictive
 #'   distribution (\code{\link[rstantools]{posterior_predict}}).
-#'   \cr \cr
-#'   \strong{Zero-Inflated and Zero-Inflated Mixed Models with brms}
-#'   \cr \cr
+#'   }
+#'   \subsection{Zero-Inflated and Zero-Inflated Mixed Models with brms}{
 #'   Models of class \code{brmsfit} always condition on the zero-inflation
 #'   component, if the model has such a component. Hence, there is no
 #'   \code{type = "fe.zi"} nor \code{type = "re.zi"} for \code{brmsfit}-models,
 #'   because predictions are based on draws of the posterior distribution,
 #'   which already account for the zero-inflation part of the model.
-#'   \cr \cr
-#'   \strong{Zero-Inflated and Zero-Inflated Mixed Models with glmmTMB}
-#'   \cr \cr
+#'   }
+#'   \subsection{Zero-Inflated and Zero-Inflated Mixed Models with glmmTMB}{
 #'   If \code{model} is of class \code{glmmTMB}, \code{hurdle}, \code{zeroinfl}
 #'   or \code{zerotrunc}, simulations from a multivariate normal distribution
 #'   (see \code{\link[MASS]{mvrnorm}}) are drawn to calculate \code{mu*(1-p)}.
@@ -290,9 +269,8 @@
 #'   uncertainties into account are simulations based on \code{simulate()}, which
 #'   is used when \code{type = "sim"} (see Brooks et al. 2017, pp.392-393 for
 #'   details).
-#'   \cr \cr
-#'   \strong{MixMod-models from GLMMadaptive}
-#'   \cr \cr
+#'   }
+#'   \subsection{MixMod-models from GLMMadaptive}{
 #'   Predicted values for the fixed effects component (\code{type = "fe"} or
 #'   \code{type = "fe.zi"}) are based on \code{predict(..., type = "mean_subject")},
 #'   while predicted values for random effects components (\code{type = "re"} or
@@ -301,6 +279,7 @@
 #'   requires the response variable to be defined in the \code{newdata}-argument
 #'   of \code{predict()}, which will be set to its typical value (see
 #'   \code{\link[sjmisc]{typical_value}}).
+#'   }
 #'
 #' @references \itemize{
 #'    \item Brooks ME, Kristensen K, Benthem KJ van, Magnusson A, Berg CW, Nielsen A, et al. glmmTMB Balances Speed and Flexibility Among Packages for Zero-inflated Generalized Linear Mixed Modeling. The R Journal. 2017;9: 378-400.
@@ -308,26 +287,25 @@
 #'  }
 #'
 #' @note
-#'   Since data for \code{ggaverage()} comes from the model frame, not all
-#'   possible combinations of values in \code{terms} might be present in the data,
-#'   thus lines or confidence bands from \code{plot()} might not span over
-#'   the complete x-axis-range.
-#'   \cr \cr
+#'   \subsection{Multinomial Models}{
 #'   \code{polr}-, \code{clm}-models, or more generally speaking, models with
 #'   ordinal or multinominal outcomes, have an additional column
 #'   \code{response.level}, which indicates with which level of the response
 #'   variable the predicted values are associated.
-#'   \cr \cr
+#'   }
+#'   \subsection{Printing Results}{
 #'   The \code{print()}-method gives a clean output (especially for predictions
 #'   by groups), and indicates at which values covariates were held constant.
 #'   Furthermore, the \code{print()}-method has the arguments \code{digits} and
 #'   \code{n} to control number of decimals and lines to be printed, and an
 #'   argument \code{x.lab} to print factor-levels instead of numeric values
 #'   if \code{x} is a factor.
-#'   \cr \cr
+#'   }
+#'   \subsection{Limitations}{
 #'   The support for some models, for example from package \pkg{MCMCglmm}, is
 #'   rather experimental and may fail for certain models. If you encounter
 #'   any errors, please file an issue at \url{https://github.com/strengejacke/ggeffects/issues}.
+#'   }
 #'
 #' @return A data frame (with \code{ggeffects} class attribute) with consistent
 #'   data columns:
@@ -337,8 +315,6 @@
 #'           \item{\code{std.error}}{the standard error of the predictions.}
 #'           \item{\code{conf.low}}{the lower bound of the confidence interval for the predicted values.}
 #'           \item{\code{conf.high}}{the upper bound of the confidence interval for the predicted values.}
-#'           \item{\code{observed}}{if \code{full.data = TRUE}, this columns contains the observed values (the response vector).}
-#'           \item{\code{residuals}}{if \code{full.data = TRUE}, this columns contains residuals.}
 #'           \item{\code{group}}{the grouping level from the second term in \code{terms}, used as grouping-aesthetics in plots.}
 #'           \item{\code{facet}}{the grouping level from the third term in \code{terms}, used to indicate facets in plots.}
 #'         }
@@ -357,7 +333,6 @@
 #' fit <- lm(barthtot ~ c12hour + neg_c_7 + c161sex + c172code, data = efc)
 #'
 #' ggpredict(fit, terms = "c12hour")
-#' ggpredict(fit, terms = "c12hour", full.data = TRUE)
 #' ggpredict(fit, terms = c("c12hour", "c172code"))
 #' ggpredict(fit, terms = c("c12hour", "c172code", "c161sex"))
 #'
@@ -382,31 +357,12 @@
 #'   geom_line() +
 #'   geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = .1)
 #'
-#' # with "full.data = TRUE", remaining covariates vary between
-#' # observations, so fitted values can be plotted
-#' mydf <- ggpredict(fit, terms = "c12hour", full.data = TRUE)
-#' ggplot(mydf, aes(x, predicted)) + geom_point()
-#'
-#' # you can add a smoothing-geom to show the linear trend of fitted values
-#' ggplot(mydf, aes(x, predicted)) +
-#'   geom_smooth(method = "lm", se = FALSE) +
-#'   geom_point()
-#'
 #' # three variables, so we can use facets and groups
-#' mydf <- ggpredict(
-#'   fit,
-#'   terms = c("c12hour", "c161sex", "c172code"),
-#'   full.data = TRUE
-#' )
+#' mydf <- ggpredict(fit, terms = c("c12hour", "c161sex", "c172code"))
 #' ggplot(mydf, aes(x = x, y = predicted, colour = group)) +
 #'   stat_smooth(method = "lm", se = FALSE) +
 #'   facet_wrap(~facet, ncol = 2)
 #'
-#' # average marginal effects
-#' mydf <- ggaverage(fit, terms = c("c12hour", "c172code"))
-#' ggplot(mydf, aes(x = x, y = predicted, colour = group)) +
-#'   stat_smooth(method = "lm", se = FALSE)
-#'
 #' # select specific levels for grouping terms
 #' mydf <- ggpredict(fit, terms = c("c12hour", "c172code [1,3]", "c161sex"))
 #' ggplot(mydf, aes(x = x, y = predicted, colour = group)) +
@@ -436,7 +392,7 @@
 #'     aes(ymin = conf.low, ymax = conf.high),
 #'     position = position_dodge(.1)
 #'   ) +
-#'   scale_x_continuous(breaks = 1:3, labels = get_x_labels(dat))
+#'   scale_x_discrete(breaks = 1:3, labels = get_x_labels(dat))
 #'
 #' # 3-way-interaction with 2 continuous variables
 #' data(efc)
@@ -459,11 +415,11 @@
 #' \dontrun{
 #' plot(dat, ci = FALSE)}
 #'
-#' # use factor levels as x-column in returned data frame
+#' # use numeric values as x-column in returned data frame
 #' data(efc)
 #' efc$c161sex <- as_label(efc$c161sex)
 #' fit <- lm(neg_c_7 ~ c12hour + c161sex, data = efc)
-#' ggpredict(fit, terms = "c161sex", x.as.factor = TRUE)
+#' ggpredict(fit, terms = "c161sex", x.as.factor = FALSE)
 #'
 #' # marginal effects for polynomial terms
 #' data(efc)
@@ -475,11 +431,11 @@
 #' ggeffect(fit, terms = "e17age")
 #'
 #' @importFrom stats predict predict.glm na.omit
-#' @importFrom dplyr select mutate case_when arrange n_distinct
+#' @importFrom dplyr select mutate case_when arrange
 #' @importFrom sjmisc to_factor is_num_fac remove_empty_cols
 #' @importFrom purrr map
 #' @importFrom sjlabelled as_numeric
-#' @importFrom insight find_random find_predictors model_info find_formula find_variables
+#' @importFrom insight find_random find_predictors model_info find_formula
 #' @export
 ggpredict <- function(model,
                       terms,
@@ -487,9 +443,9 @@ ggpredict <- function(model,
                       type = c("fe", "re", "fe.zi", "re.zi", "sim", "surv", "cumhaz", "debug"),
                       typical = "mean",
                       condition = NULL,
+                      back.transform = TRUE,
                       ppd = FALSE,
-                      x.as.factor = FALSE,
-                      full.data = FALSE,
+                      x.as.factor = TRUE,
                       vcov.fun = NULL,
                       vcov.type = NULL,
                       vcov.args = NULL,
@@ -510,10 +466,7 @@ ggpredict <- function(model,
 
   # for gamm/gamm4 objects, we have a list with two items, mer and gam
   # extract just the mer-part then
-  is.gamm <- inherits(model, c("list", "gamm")) && all(names(model %in% c("lme", "gam")))
-  is.gamm4 <- inherits(model, "list") && all(names(model %in% c("mer", "gam")))
-
-  if (is.gamm || is.gamm4) model <- model$gam
+  if (is.gamm(model) || is.gamm4(model)) model <- model$gam
 
   if (inherits(model, "list")) {
     res <- purrr::map(model, ~ggpredict_helper(
@@ -521,11 +474,11 @@ ggpredict <- function(model,
       terms = terms,
       ci.lvl = ci.lvl,
       type = type,
-      full.data = full.data,
       typical = typical,
       ppd = ppd,
       x.as.factor = x.as.factor,
       condition = condition,
+      back.transform = back.transform,
       vcov.fun = vcov.fun,
       vcov.type = vcov.type,
       vcov.args = vcov.args,
@@ -544,11 +497,11 @@ ggpredict <- function(model,
             terms = .x,
             ci.lvl = ci.lvl,
             type = type,
-            full.data = full.data,
             typical = typical,
             ppd = ppd,
             x.as.factor = x.as.factor,
             condition = condition,
+            back.transform = back.transform,
             vcov.fun = vcov.fun,
             vcov.type = vcov.type,
             vcov.args = vcov.args,
@@ -568,11 +521,11 @@ ggpredict <- function(model,
         terms = terms,
         ci.lvl = ci.lvl,
         type = type,
-        full.data = full.data,
         typical = typical,
         ppd = ppd,
         x.as.factor = x.as.factor,
         condition = condition,
+        back.transform = back.transform,
         vcov.fun = vcov.fun,
         vcov.type = vcov.type,
         vcov.args = vcov.args,
@@ -582,7 +535,7 @@ ggpredict <- function(model,
     }
   }
 
-  attr(res, "model.name") <- model.name
+  if (!is.null(res)) attr(res, "model.name") <- model.name
   res
 }
 
@@ -593,48 +546,46 @@ ggpredict_helper <- function(model,
                              terms,
                              ci.lvl,
                              type,
-                             full.data,
                              typical,
                              ppd,
                              x.as.factor,
                              condition,
+                             back.transform,
                              vcov.fun,
                              vcov.type,
                              vcov.args,
                              interval,
                              ...) {
-  # check class of fitted model
-  fun <- get_predict_function(model)
 
-  # check terms argument
-  terms <- check_vars(terms, model)
-  cleaned.terms <- get_clear_vars(terms)
+  # check class of fitted model, to make sure we have just one class-attribute
+  # (while "inherits()" may return multiple attributes)
+  model.class <- get_predict_function(model)
+
+  # check terms argument, to make sure that terms were not misspelled
+  # and are indeed existing in the data
+  terms <- .check_vars(terms, model)
+  cleaned.terms <- .get_cleaned_terms(terms)
 
   # check if predictions should be made for each group level in
   # random effects models
-  if (fun %in% c("lmer", "glmer", "glmmTMB", "nlmer")) {
+  if (model.class %in% c("lmer", "glmer", "glmmTMB", "nlmer")) {
     re.terms <- insight::find_random(model, split_nested = TRUE, flatten = TRUE)
     if (!is.null(re.terms) && any(cleaned.terms %in% re.terms)) ci.lvl <- NA
   }
 
-  # check model family, do we have count model?
-  faminfo <- get_model_info(model)
+  # check model family
+  faminfo <- .get_model_info(model)
 
-  if (fun == "coxph" && type == "surv") faminfo$is_binomial <- TRUE
+  if (model.class == "coxph" && type == "surv") faminfo$is_binomial <- TRUE
 
   # get model frame
   fitfram <- insight::get_data(model)
 
-  # expand model frame to grid of unique combinations, if
-  # user not requested full data
-  if (full.data) {
-    expanded_frame <- get_sliced_data(fitfram, terms)
-  } else {
-    expanded_frame <- get_expanded_data(
-      model = model, mf = fitfram, terms = terms, typ.fun = typical,
-      condition = condition
-    )
-  }
+  # expand model frame to data grid of unique combinations
+  expanded_frame <- .get_data_grid(
+    model = model, mf = fitfram, terms = terms, typ.fun = typical,
+    condition = condition
+  )
 
   # save original frame, for labels, and original terms
   ori.mf <- fitfram
@@ -646,7 +597,7 @@ ggpredict_helper <- function(model,
 
   # compute predictions here -----
   fitfram <- select_prediction_method(
-    fun,
+    model.class,
     model,
     expanded_frame,
     ci.lvl,
@@ -663,21 +614,25 @@ ggpredict_helper <- function(model,
     ...
   )
 
+  # return if no predicted values have been computed
+  if (is.null(fitfram)) return(NULL)
+
 
   # init legend labels
   legend.labels <- NULL
 
   # for survival probabilities or cumulative hazards, we need
   # the "time" variable
-  if (fun == "coxph" && type %in% c("surv", "cumhaz")) {
+  if (model.class == "coxph" && type %in% c("surv", "cumhaz")) {
     terms <- c("time", terms)
+    cleaned.terms <- c("time", cleaned.terms)
   }
 
   # get axis titles and labels
-  all.labels <- get_all_labels(
+  all.labels <- .get_axis_titles_and_labels(
     fitfram = ori.mf,
     terms = terms,
-    fun = get_model_function(model),
+    fun = .get_model_function(model),
     faminfo = faminfo,
     no.transform = FALSE,
     type = type
@@ -691,129 +646,62 @@ ggpredict_helper <- function(model,
   # now select only relevant variables: the predictors on the x-axis,
   # the predictions and the originial response vector (needed for scatter plot)
 
-  cols.to.keep <- stats::na.omit(match(
+  mydf <- fitfram[, stats::na.omit(match(
     c(terms, "predicted", "conf.low", "conf.high", "response.level"),
     colnames(fitfram)
-  ))
-
-  mydf <- dplyr::select(fitfram, !! cols.to.keep)
+  ))]
 
 
-  # no full data for certain models
-  if (full.data && faminfo$is_ordinal) {
-    message("Argument `full.data` is not supported for ordinal or cumulative link regression model.")
-    full.data <- FALSE
-  }
+  # name and sort columns, depending on groups, facet and panel
+  mydf <- .prepare_columns(mydf, cleaned.terms)
 
+  # grouping variable may not be labelled
+  # do this here, so we convert to labelled factor later
+  mydf <- .add_labels_to_groupvariable(mydf, ori.mf, terms)
 
-  # for full data, we can also get observed and residuals
-  if (full.data) {
-    mydf <- dplyr::mutate(mydf,
-      observed = sjlabelled::as_numeric(fitfram[[1]], start.at = 0, keep.labels = F),
-      residuals = .data$observed - .data$predicted
-    )
-  } else {
-    mydf <- dplyr::mutate(mydf, observed = NA, residuals = NA)
-  }
+  # convert grouping variable to factor, for proper legend
+  mydf <- .groupvariable_to_labelled_factor(mydf)
 
-
-  # with or w/o grouping factor?
-  if (length(terms) == 1) {
-    colnames(mydf)[1] <- "x"
-    # convert to factor for proper legend
-    mydf$group <- sjmisc::to_factor(1)
-  } else {
-    # name data depending on whether we have a facet-variable or not
-    if (length(terms) == 2) {
-      # for some models, like MASS::polr, we have an additional
-      # column for the response category. So maximun ncol is 8, not 7
-      max_value <- ifelse(fun %in% c("polr", "clm", "clm2", "multinom"), 8, 7)
-      colnames(mydf)[1:2] <- c("x", "group")
-      # reorder columns
-      mydf <- mydf[, c(1, 3:max_value, 2)]
-    } else {
-      # for some models, like MASS::polr, we have an additional
-      # column for the response category. So maximun ncol is 8, not 7
-      max_value <- ifelse(fun %in% c("polr", "clm", "clm2", "multinom"), 9, 8)
-      colnames(mydf)[1:3] <- c("x", "group", "facet")
-      # reorder columns
-      mydf <- mydf[, c(1, 4:max_value, 2:3)]
-    }
-
-    # if we have no full data, grouping variable may not be labelled
-    # do this here, so we convert to labelled factor later
-    if (!full.data) mydf <- add_groupvar_labels(mydf, ori.mf, terms)
-
-    # convert to factor for proper legend
-    mydf <- groupvar_to_label(mydf)
-
-    # check if we have legend labels
-    legend.labels <- sjlabelled::get_labels(mydf$group)
-  }
+  # check if we have legend labels
+  legend.labels <- sjlabelled::get_labels(mydf$group)
 
   # if we had numeric variable w/o labels, these still might be numeric
   # make sure we have factors here for our grouping and facet variables
   if (is.numeric(mydf$group))
     mydf$group <- sjmisc::to_factor(mydf$group)
 
-  if (obj_has_name(mydf, "facet") && is.numeric(mydf$facet))
+  if (obj_has_name(mydf, "facet") && is.numeric(mydf$facet)) {
     mydf$facet <- sjmisc::to_factor(mydf$facet)
+    attr(mydf, "numeric.facet") <- TRUE
+  }
 
 
-  # remember if x is factor and if we had full data
+  # remember if x is factor
   x.is.factor <- ifelse(is.factor(mydf$x), "1", "0")
-  has.full.data <- ifelse(full.data, "1", "0")
 
   # x needs to be numeric
   if (!x.as.factor) mydf$x <- sjlabelled::as_numeric(mydf$x)
 
   # add standard errors
   se <- attr(fitfram, "std.error", exact = TRUE)
-
-  if (is.null(se))
-    se <- NA
+  if (is.null(se)) se <- NA
 
   mydf <- sjmisc::add_variables(mydf, std.error = se, .after = "predicted")
 
 
   # sort values
-  mydf <- mydf %>%
-    dplyr::arrange(.data$x, .data$group) %>%
-    sjmisc::remove_empty_cols()
-
+  mydf <- sjmisc::remove_empty_cols(mydf[order(mydf$x, mydf$group), ])
 
   # check if outcome is log-transformed, and if so,
   # back-transform predicted values to response scale
-
-  rv <- insight::find_variables(model)[["response"]]
-
-  if (any(grepl("log\\((.*)\\)", rv))) {
-
-    # do we have log-log models?
-    if (grepl("log\\(log\\((.*)\\)\\)", rv)) {
-      mydf$predicted <- exp(exp(mydf$predicted))
-      if (obj_has_name(mydf, "conf.low") && obj_has_name(mydf, "conf.high")) {
-        mydf$conf.low <- exp(exp(mydf$conf.low))
-        mydf$conf.high <- exp(exp(mydf$conf.high))
-      }
-    } else {
-      mydf$predicted <- exp(mydf$predicted)
-      if (obj_has_name(mydf, "conf.low") && obj_has_name(mydf, "conf.high")) {
-        mydf$conf.low <- exp(mydf$conf.low)
-        mydf$conf.high <- exp(mydf$conf.high)
-      }
-    }
-
-    message("Model has log-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the log-scale.")
-  }
-
+  mydf <- .back_transform_response(model, mydf, back.transform)
 
   # add raw data as well
-  attr(mydf, "rawdata") <- get_raw_data(model, ori.mf, terms)
+  attr(mydf, "rawdata") <- .get_raw_data(model, ori.mf, terms)
 
 
   # set attributes with necessary information
-  set_attributes_and_class(
+  .set_attributes_and_class(
     data = mydf,
     model = model,
     t.title = all.labels$t.title,
@@ -824,11 +712,10 @@ ggpredict_helper <- function(model,
     x.axis.labels = all.labels$axis.labels,
     faminfo = faminfo,
     x.is.factor = x.is.factor,
-    full.data = has.full.data,
     constant.values = attr(expanded_frame, "constant.values", exact = TRUE),
     terms = cleaned.terms,
     ori.terms = ori.terms,
-    at.list = get_expanded_data(
+    at.list = .get_data_grid(
       model = model, mf = ori.mf, terms = ori.terms, typ.fun = typical,
       condition = condition, pretty.message = FALSE, emmeans.only = TRUE
     ),
@@ -836,3 +723,10 @@ ggpredict_helper <- function(model,
     prediction.interval = attr(fitfram, "prediction.interval", exact = TRUE)
   )
 }
+
+
+#' @rdname ggpredict
+#' @export
+ggaverage <- function(...) {
+  stop("'ggaverage()' was removed. Please use ' ggpredict()', 'ggemmeans()' or 'ggeffect()' instead.", call. = FALSE)
+}
