@@ -1,7 +1,7 @@
 # select prediction method, based on model-object
 #' @importFrom sjmisc add_variables
 #' @importFrom insight find_response get_response get_data model_info link_inverse is_multivariate
-select_prediction_method <- function(fun,
+select_prediction_method <- function(model.class,
                                      model,
                                      expanded_frame,
                                      ci.lvl,
@@ -20,81 +20,81 @@ select_prediction_method <- function(fun,
   linv <- insight::link_inverse(model)
   if (is.null(linv)) linv <- function(x) x
 
-  if (fun == "svyglm") {
+  if (model.class == "svyglm") {
     fitfram <- get_predictions_svyglm(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun == "svyglm.nb") {
-    fitfram <- get_predictions_svyglmnb(model, expanded_frame, ci.lvl, linv, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
-  } else if (fun == "stanreg") {
+  } else if (model.class == "svyglm.nb") {
+    fitfram <- get_predictions_svyglmnb(model, expanded_frame, ci.lvl, linv, model.class, typical, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
+  } else if (model.class == "stanreg") {
     fitfram <- get_predictions_stan(model, expanded_frame, ci.lvl, type, faminfo, ppd, terms, ...)
-  } else if (fun == "brmsfit") {
+  } else if (model.class == "brmsfit") {
     fitfram <- get_predictions_stan(model, expanded_frame, ci.lvl, type, faminfo, ppd, terms, ...)
-  } else if (fun == "coxph" && type != "surv" && type != "cumhaz") {
-    fitfram <- get_predictions_coxph(model, expanded_frame, ci.lvl, typical, fun, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
-  } else if (fun == "coxph" && type %in% c("surv", "cumhaz")) {
+  } else if (model.class == "coxph" && type != "surv" && type != "cumhaz") {
+    fitfram <- get_predictions_coxph(model, expanded_frame, ci.lvl, typical, model.class, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
+  } else if (model.class == "coxph" && type %in% c("surv", "cumhaz")) {
     fitfram <- get_predictions_survival(model, expanded_frame, ci.lvl, type, terms, ...)
-  } else if (fun == "ols") {
+  } else if (model.class == "ols") {
     fitfram <- get_predictions_ols(model, expanded_frame, ci.lvl, ...)
-  } else if (fun == "lrm") {
+  } else if (model.class == "lrm") {
     fitfram <- get_predictions_lrm(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun == "glimML") {
+  } else if (model.class == "glimML") {
     fitfram <- get_predictions_glimML(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun == "glmmTMB") {
+  } else if (model.class == "glmmTMB") {
     fitfram <- get_predictions_glmmTMB(model, expanded_frame, ci.lvl, linv, type, terms, typical, condition, ...)
-  } else if (fun == "wbm") {
+  } else if (model.class == "wbm") {
     fitfram <- get_predictions_wbm(model, expanded_frame, ci.lvl, linv, type, terms, typical, condition, ...)
-  } else if (fun %in% c("lmer", "nlmer", "glmer")) {
+  } else if (model.class %in% c("lmer", "nlmer", "glmer")) {
     fitfram <- get_predictions_merMod(model, expanded_frame, ci.lvl, linv, type, terms, typical, condition, ...)
-  } else if (fun == "geeglm") {
+  } else if (model.class == "geeglm") {
     fitfram <- get_predictions_geeglm(model, expanded_frame, ...)
-  } else if (fun == "gamlss") {
-    fitfram <- get_predictions_gamlss(model, expanded_frame, ci.lvl, linv, terms, fun, typical, condition, ...)
-  } else if (fun == "gam") {
-    fitfram <- get_predictions_gam(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun == "Gam") {
-    fitfram <- get_predictions_Gam(model, expanded_frame, ci.lvl, linv, typical, terms, fun, condition, ...)
-  # } else if (fun == "vgam") {
+  } else if (model.class == "gamlss") {
+    fitfram <- get_predictions_gamlss(model, expanded_frame, ci.lvl, linv, terms, model.class, typical, condition, ...)
+  } else if (model.class == "gam") {
+    fitfram <- get_predictions_gam(model, expanded_frame, ci.lvl, linv, type, ...)
+  } else if (model.class == "Gam") {
+    fitfram <- get_predictions_Gam(model, expanded_frame, ci.lvl, linv, typical, terms, model.class, condition, ...)
+  # } else if (model.class == "vgam") {
   # fitfram <- get_predictions_vgam(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun == "vglm") {
+  } else if (model.class == "vglm") {
     fitfram <- get_predictions_vglm(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun == "tobit") {
+  } else if (model.class == "tobit") {
     fitfram <- get_predictions_tobit(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun %in% c("lme", "gls", "plm")) {
-    fitfram <- get_predictions_lme(model, expanded_frame, ci.lvl, linv, type, terms, typical, fun, vcov.fun, vcov.type, vcov.args, condition, ...)
-  } else if (fun == "gee") {
+  } else if (model.class %in% c("lme", "gls", "plm")) {
+    fitfram <- get_predictions_lme(model, expanded_frame, ci.lvl, linv, type, terms, typical, model.class, vcov.fun, vcov.type, vcov.args, condition, ...)
+  } else if (model.class == "gee") {
     fitfram <- get_predictions_gee(model, terms, ...)
-  } else if (fun == "multinom") {
-    fitfram <- get_predictions_multinom(model, expanded_frame, ci.lvl, linv, typical, terms, fun, ...)
-  } else if (fun == "clmm") {
+  } else if (model.class == "multinom") {
+    fitfram <- get_predictions_multinom(model, expanded_frame, ci.lvl, linv, typical, terms, model.class, ...)
+  } else if (model.class == "clmm") {
     fitfram <- get_predictions_clmm(model, terms, typical, condition, ci.lvl, linv, ...)
-  } else if (fun == "clm") {
+  } else if (model.class == "clm") {
     fitfram <- get_predictions_clm(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun == "clm2") {
+  } else if (model.class == "clm2") {
     fitfram <- get_predictions_clm2(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun == "Zelig-relogit") {
+  } else if (model.class == "Zelig-relogit") {
     fitfram <- get_predictions_zelig(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun == "polr") {
-    fitfram <- get_predictions_polr(model, expanded_frame, ci.lvl, linv, typical, terms, fun, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
-  } else if (fun %in% c("betareg", "truncreg", "ivreg", "vgam")) {
-    fitfram <- get_predictions_generic2(model, expanded_frame, ci.lvl, linv, type, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
-  } else if (fun %in% c("zeroinfl", "hurdle", "zerotrunc")) {
-    fitfram <- get_predictions_zeroinfl(model, expanded_frame, ci.lvl, linv, type, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, ...)
-  } else if (fun %in% c("glm", "glm.nb")) {
-    fitfram <- get_predictions_glm(model, expanded_frame, ci.lvl, linv, typical, fun, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
-  } else if (fun %in% c("rq")) {
+  } else if (model.class == "polr") {
+    fitfram <- get_predictions_polr(model, expanded_frame, ci.lvl, linv, typical, terms, model.class, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
+  } else if (model.class %in% c("betareg", "truncreg", "ivreg", "vgam")) {
+    fitfram <- get_predictions_generic2(model, expanded_frame, ci.lvl, linv, type, model.class, typical, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
+  } else if (model.class %in% c("zeroinfl", "hurdle", "zerotrunc")) {
+    fitfram <- get_predictions_zeroinfl(model, expanded_frame, ci.lvl, linv, type, model.class, typical, terms, vcov.fun, vcov.type, vcov.args, condition, ...)
+  } else if (model.class %in% c("glm", "glm.nb")) {
+    fitfram <- get_predictions_glm(model, expanded_frame, ci.lvl, linv, typical, model.class, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
+  } else if (model.class %in% c("rq")) {
     fitfram <- get_predictions_rq(model, expanded_frame, ci.lvl, ...)
-  } else if (fun %in% c("lmrob")) {
+  } else if (model.class %in% c("lmrob")) {
     fitfram <- get_predictions_lmrob_base(model, expanded_frame, ci.lvl, ...)
-  } else if (fun %in% c("glmrob")) {
+  } else if (model.class %in% c("glmrob")) {
     fitfram <- get_predictions_glmrob_base(model, expanded_frame, ci.lvl, linv, ...)
-  } else if (fun %in% c("glmRob")) {
-    fitfram <- get_predictions_glmRob(model, expanded_frame, ci.lvl, linv, typical, fun, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
-  } else if (fun == "logistf") {
+  } else if (model.class %in% c("glmRob")) {
+    fitfram <- get_predictions_glmRob(model, expanded_frame, ci.lvl, linv, typical, model.class, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
+  } else if (model.class == "logistf") {
     fitfram <- get_predictions_logistf(model, expanded_frame, terms, ...)
-  } else if (fun == "lm") {
-    fitfram <- get_predictions_lm(model, expanded_frame, ci.lvl, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
-  } else if (fun == "MixMod") {
+  } else if (model.class == "lm") {
+    fitfram <- get_predictions_lm(model, expanded_frame, ci.lvl, model.class, typical, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
+  } else if (model.class == "MixMod") {
     fitfram <- get_predictions_MixMod(model, expanded_frame, ci.lvl, linv, type, terms, typical, condition, ...)
-  } else if (fun == "MCMCglmm") {
+  } else if (model.class == "MCMCglmm") {
     fitfram <- get_predictions_MCMCglmm(model, expanded_frame, ci.lvl, interval, ...)
   } else {
     fitfram <- get_predictions_generic(model, expanded_frame, linv, ...)
@@ -104,7 +104,8 @@ select_prediction_method <- function(fun,
 }
 
 
-get_base_fitfram <- function(model, fitfram, linv, prdat, se, ci.lvl, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition = NULL, interval = NULL) {
+
+.get_base_fitfram <- function(model, fitfram, linv, prdat, se, ci.lvl, model.class, typical, terms, vcov.fun, vcov.type, vcov.args, condition = NULL, interval = NULL) {
 
   # compute ci, two-ways
 
@@ -139,12 +140,12 @@ get_base_fitfram <- function(model, fitfram, linv, prdat, se, ci.lvl, fun, typic
 
   if (!is.null(vcov.fun) || (!is.null(interval) && se)) {
     se.pred <-
-      get_se_from_vcov(
+      .get_se_from_vcov(
         model = model,
         fitfram = fitfram,
         typical = typical,
         terms = terms,
-        fun = fun,
+        model.class = model.class,
         vcov.fun = vcov.fun,
         vcov.type = vcov.type,
         vcov.args = vcov.args,
