@@ -1,4 +1,4 @@
-set_attributes_and_class <- function(data, model, t.title, x.title, y.title, l.title, legend.labels, x.axis.labels, faminfo, x.is.factor, full.data, constant.values = NULL, terms = NULL, ori.terms = NULL, at.list = NULL, n.trials = NULL, prediction.interval = NULL) {
+.set_attributes_and_class <- function(data, model, t.title, x.title, y.title, l.title, legend.labels, x.axis.labels, faminfo, x.is.factor, constant.values = NULL, terms = NULL, ori.terms = NULL, at.list = NULL, n.trials = NULL, prediction.interval = NULL) {
   # check correct labels
   if (!is.null(x.axis.labels) && length(x.axis.labels) != length(stats::na.omit(unique(data$x))))
     x.axis.labels <- as.vector(sort(stats::na.omit(unique(data$x))))
@@ -16,7 +16,6 @@ set_attributes_and_class <- function(data, model, t.title, x.title, y.title, l.t
   attr(data, "legend.labels") <- legend.labels
   attr(data, "x.axis.labels") <- x.axis.labels
   attr(data, "x.is.factor") <- x.is.factor
-  attr(data, "full.data") <- full.data
   attr(data, "constant.values") <- constant.values
   attr(data, "terms") <- terms
   attr(data, "ori.terms") <- ori.terms
@@ -26,12 +25,12 @@ set_attributes_and_class <- function(data, model, t.title, x.title, y.title, l.t
   # remember fit family
   attr(data, "family") <- faminfo$family
   attr(data, "link") <- faminfo$link_function
-  attr(data, "logistic") <- ifelse(faminfo$is_binomial, "1", "0")
+  attr(data, "logistic") <- ifelse(faminfo$is_binomial || faminfo$is_ordinal, "1", "0")
   attr(data, "is.trial") <- ifelse(faminfo$is_trial && inherits(model, "brmsfit"), "1", "0")
   attr(data, "n.trials") <- n.trials
 
   # and model-function
-  attr(data, "fitfun") <- get_model_function(model)
+  attr(data, "fitfun") <- .get_model_function(model)
 
   # add class attribute
   class(data) <- c("ggeffects", class(data))
